// java wrapper for vtkGenericProbeFilter object
//

package vtk;
import vtk.*;

public class vtkGenericProbeFilter extends vtkDataSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetSourceData_2(vtkGenericDataSet id0);
  public void SetSourceData(vtkGenericDataSet id0)
    { SetSourceData_2(id0); }

  private native long GetSource_3();
  public vtkGenericDataSet GetSource() {
    long temp = GetSource_3();

    if (temp == 0) return null;
    return (vtkGenericDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetValidPoints_4();
  public vtkIdTypeArray GetValidPoints() {
    long temp = GetValidPoints_4();

    if (temp == 0) return null;
    return (vtkIdTypeArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkGenericProbeFilter() { super(); }

  public vtkGenericProbeFilter(long id) { super(id); }
  public native long   VTKInit();

}
